@@ -18,6 +18,11 @@ service_mapping = {
         "Language",
         "Analytics & AI"
     ],
+    "ai-data-platform": [
+        "ai_data_platform",
+        "AiDataPlatform Control Plane",
+        "Others"
+    ],
     "ai-document": [
         "ai_document",
         "Document Understanding",
@@ -38,11 +43,6 @@ service_mapping = {
         "Announcements Service",
         "Governance & Administration"
     ],
-    "anomaly-detection": [
-        "ai_anomaly_detection",
-        "Anomaly Detection",
-        "Analytics & AI"
-    ],
     "api-gateway": [
         "apigateway",
         "API Gateway",
@@ -245,7 +245,7 @@ service_mapping = {
     ],
     "dbmulticloud": [
         "dbmulticloud",
-        "Oracle Database MultiCloud Data plane Integration",
+        "Oracle Database MultiCloud Data Plane Integration",
         "Others"
     ],
     "dbtools": [
@@ -288,11 +288,6 @@ service_mapping = {
         "DNS",
         "Networking"
     ],
-    "dts": [
-        "dts",
-        "Data Transfer Service",
-        "Migration"
-    ],
     "em-warehouse": [
         "em_warehouse",
         "EM Warehouse",
@@ -398,6 +393,11 @@ service_mapping = {
         "Oracle Integration",
         "Others"
     ],
+    "iot": [
+        "iot",
+        "Internet of Things",
+        "Others"
+    ],
     "jms": [
         "jms",
         "Java Management Service Fleets",
@@ -405,7 +405,17 @@ service_mapping = {
     ],
     "jms-java-downloads": [
         "jms_java_downloads",
-        "Java Management Service Download",
+        "Java Management Service Java Download",
+        "Others"
+    ],
+    "jms-utils": [
+        "jms_utils",
+        "Java Management Service Utilities",
+        "Others"
+    ],
+    "kafka": [
+        "managed_kafka",
+        "Oracle Streaming with Apache Kafka (OSAK)",
         "Others"
     ],
     "kms": [
@@ -598,11 +608,6 @@ service_mapping = {
         "Object Storage Service",
         "Storage"
     ],
-    "os-management": [
-        "os_management",
-        "OS Management",
-        "Compute"
-    ],
     "os-management-hub": [
         "os_management_hub",
         "OS Management Hub",
@@ -653,6 +658,11 @@ service_mapping = {
         "OCI Cache",
         "Others"
     ],
+    "resource-analytics": [
+        "resource_analytics",
+        "Resource Analytics",
+        "Others"
+    ],
     "resource-manager": [
         "resource_manager",
         "Resource Manager",
@@ -698,11 +708,6 @@ service_mapping = {
         "Service Manager Proxy",
         "Others"
     ],
-    "service-mesh": [
-        "service_mesh",
-        "Service Mesh",
-        "Developer Services"
-    ],
     "speech": [
         "ai_speech",
         "Speech",
